@@ -3,7 +3,7 @@
 #
 #  Written by Curtis Olson.  Started September 29, 1994.
 #
-#  Copyright (C) 1994  Curtis L. Olson  - curt@sledge.mn.org
+#  Copyright (C) 1994, 1995, 1996  Curtis L. Olson  - curt@sledge.mn.org
 #
 #  This program is free software; you can redistribute it and/or modify
 #  it under the terms of the GNU General Public License as published by
@@ -19,7 +19,7 @@
 #  along with this program; if not, write to the Free Software
 #  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
-# $Id: categories.pl,v 1.4 1994/11/07 23:13:52 clolson Exp $
+# $Id: categories.pl,v 1.10 1996/01/21 02:18:46 curt Exp $
 # (Log is kept at end of this file)
 
 
@@ -34,6 +34,7 @@
 sub init_cats {
     # out: result
 
+    %CATS = ();
     $sorted_catkeys = 0;
 
     return "ok";
@@ -57,9 +58,9 @@ sub edit_cat {
     local($cat) = @_;
 
     $sorted_catkeys = 0;
-    ($key, $desc, $tax) = split(/:/, $cat);
+    ($key, $desc, $tax) = split(/\t/, $cat);
 
-    $CATS{$key} = "$desc:$tax";
+    $CATS{$key} = "$desc\t$tax";
 
     print DEBUG "cat-edit:  $cat\n" if $debug;
 
@@ -75,9 +76,9 @@ sub insert_cat {
     local($cat) = @_;
 
     $sorted_catkeys = 0;
-    ($key, $desc, $tax) = split(/:/, $cat);
+    ($key, $desc, $tax) = split(/\t/, $cat);
 
-    $CATS{$key} = "$desc:$tax";
+    $CATS{$key} = "$desc\t$tax";
 
     print DEBUG "cat-insert:  $cat\n" if $debug;
 
@@ -92,7 +93,7 @@ sub delete_cat {
     local($cat) = @_;
 
     $sorted_catkeys = 0;
-    ($key, $desc, $tax) = split(/:/, $cat);
+    ($key, $desc, $tax) = split(/\t/, $cat);
 
     delete $CATS{$key};
 
@@ -145,7 +146,7 @@ sub all_cats {
     }
 
     foreach $key (@CATKEYS) {
-	print ("$key:$CATS{$key}\n");
+	print ("$key\t$CATS{$key}\n");
     }
 
     $| = 1;				# turn buffer flushing back on
@@ -155,7 +156,7 @@ sub all_cats {
 
 
 # load a categories list
-sub load_cats {
+sub load_dbm_cats {
     # in: file base name
     # out: result
 
@@ -171,7 +172,7 @@ sub load_cats {
 
 
 # load a categories list
-sub import_cats {
+sub load_cats {
     # in: file base name
     # out: result
 
@@ -183,6 +184,9 @@ sub import_cats {
 
     while ( <LOADCATS> ) {
 	chop;
+	if ( ! m/\t/ ) {
+	    s/:/\t/g;
+	}
 	&insert_cat($_);
     }
 
@@ -199,14 +203,16 @@ sub save_cats {
 
     local($file) = @_;
 
+    print DEBUG "save_cats to file $file\n" if $debug;
+
     if ($sorted_catkeys == 0) {
 	&sort_catkeys();
     }
 
-    open(SAVECATS, ">$file.cat") || return "error";
+    open(SAVECATS, ">$file") || return "error";
 
     foreach $key (@CATKEYS) {
-        print( SAVECATS "$key:$CATS{$key}\n" );
+        print( SAVECATS "$key\t$CATS{$key}\n" );
     }
 
     close(SAVECATS);
@@ -220,6 +226,26 @@ sub save_cats {
 
 # ----------------------------------------------------------------------------
 # $Log: categories.pl,v $
+# Revision 1.10  1996/01/21  02:18:46  curt
+# Modified Files:  categories.pl common.pl engine.pl export.pl file.pl import.pl
+#                  log.pl memorized.pl reports.pl wrapper.pl
+#   Updated copyright date.
+#
+# Revision 1.9  1995/08/18  11:31:48  curt
+# Found small bug for when loading a ":" delimited file.
+#
+# Revision 1.8  1995/07/20  11:18:47  curt
+# Spelling fixes ...
+#
+# Revision 1.7  1995/07/08  01:42:41  curt
+# Change delimter from ":" to "\t"
+#
+# Revision 1.6  1995/06/04  13:28:45  curt
+# Categories are now saved in text file format rather than dbm format.
+#
+# Revision 1.5  1995/04/24  02:55:53  curt
+# Changed "proc foo 0 { bar }" to "proc foo {} { bar }"
+#
 # Revision 1.4  1994/11/07  23:13:52  clolson
 # Working on interactive category viewing/editing
 #
@@ -229,7 +255,7 @@ sub save_cats {
 #
 # Revision 1.2  1994/10/31  23:14:38  clolson
 # Started tracking towards cbbsh (the text only version).  Chris Browne has
-# some good ideas, so I am trying to incorperate them, and make my stuff
+# some good ideas, so I am trying to incorporate them, and make my stuff
 # compatible with his.
 #
 # Revision 1.1  1994/10/31  15:18:51  curt
