@@ -3,7 +3,7 @@
 #
 #  Written by Curtis Olson.  Started August 22, 1994.
 #
-#  Copyright (C) 1994  Curtis L. Olson  - curt@sledge.mn.org
+#  Copyright (C) 1994, 1995, 1996  Curtis L. Olson  - curt@sledge.mn.org
 #
 #  This program is free software; you can redistribute it and/or modify
 #  it under the terms of the GNU General Public License as published by
@@ -19,10 +19,14 @@
 #  along with this program; if not, write to the Free Software
 #  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
-# $Id: common.pl,v 1.3 1995/02/23 05:08:43 curt Exp $
+# $Id: common.pl,v 1.8 1996/01/21 02:18:47 curt Exp $
 # (Log is kept at end of this file)
 
 
+# We need a version number
+$version = "Version <not_installed> (Alpha)";
+($junk1, $version_num, $junk2) = split(/ +/, $version);
+
 # Contributed by Christopher Browne, Oct. 24/94
 sub pad { 
     return sprintf("%02d", @_[0]); 
@@ -53,11 +57,38 @@ sub file_basename {
 }
 
 
+# return the file name root (ending at last ".")
+sub file_root {
+    local($file) = @_;
+    local($pos);
+
+    $pos = rindex($file, ".");
+    return substr($file, 0, $pos);
+}
+
+
+# return the file name extension (starting at first ".")
+sub file_extension {
+    local($file) = @_;
+    local($pos);
+
+    $pos = rindex($file, ".");
+    return substr($file, ($pos + 1));
+}
+
+
 # return current date in a nice format
 sub nice_date {
+    local($date_fmt) = @_;
+
     local($sec,$min,$hour,$mday,$mon,$year,$wday,$yday,$isdst) = 
         localtime(time);
-    return &pad($mon+1) . "/" . &pad($mday) . "/" . &pad($year);
+
+    if ( $date_fmt == 1 ) {
+        return &pad($mon+1) . "/" . &pad($mday) . "/" . &pad($year);
+    } else {
+        return &pad($mday) . "/" . &pad($mon+1) . "/" . &pad($year);
+    }
 }
 
 
@@ -74,6 +105,25 @@ sub raw_date {
 
 # ----------------------------------------------------------------------------
 # $Log: common.pl,v $
+# Revision 1.8  1996/01/21  02:18:47  curt
+# Modified Files:  categories.pl common.pl engine.pl export.pl file.pl import.pl
+#                  log.pl memorized.pl reports.pl wrapper.pl
+#   Updated copyright date.
+#
+# Revision 1.7  1995/08/18  11:34:06  curt
+# Added support for the international date format.
+#
+# Revision 1.6  1995/07/08  01:49:00  curt
+# Keep track of version number (ala the tk side)
+#
+# Revision 1.5  1995/06/04  13:23:12  curt
+# file_extension() now returns everything after the *last* dot instead of
+# everything after the first.
+#
+# Revision 1.4  1995/04/24  01:57:19  curt
+# Split of menu setup functions into a separate file:  menu.tk
+# Started rearranging structure to support multiple file formats.
+#
 # Revision 1.3  1995/02/23  05:08:43  curt
 # Removed dependencies on tclX.
 #
