@@ -8,7 +8,7 @@
 #
 #  Written by Curtis Olson.  Started February 10, 1995.
 #
-#  Copyright (C) 1994  Curtis L. Olson  - curt@sledge.mn.org
+#  Copyright (C) 1995, 1996  Curtis L. Olson  - curt@sledge.mn.org
 #
 #  This program is free software; you can redistribute it and/or modify
 #  it under the terms of the GNU General Public License as published by
@@ -24,7 +24,7 @@
 #  along with this program; if not, write to the Free Software
 #  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
-# $Id: yearend.pl,v 1.1 1995/02/23 04:54:24 curt Exp $
+# $Id: yearend.pl,v 1.2 1996/01/21 00:28:27 curt Exp $
 # (Log is kept at end of this file)
 
 
@@ -65,7 +65,7 @@ open(OUTPUT, ">$outfile");
 $result = &first_trans();
 while ( $result ne "none" ) {
     ($key, $date, $check, $desc, $debit, $credit, $cat, $com, $cleared,
-     $total) = split(/:/, $result);
+     $total) = split(/\t/, $result);
 
     if ( $cleared ne "x" ) {
 	print (OUTPUT "$TRANS{$key}\n");
@@ -83,10 +83,16 @@ while ( $result ne "none" ) {
 
 close(OUTPUT);
 
+(&save_trans("$account") eq "ok") || die "Cannot save account:  $account";
+
 print "\n";
 
 # ----------------------------------------------------------------------------
 # $Log: yearend.pl,v $
-% Revision 1.1  1995/02/23  04:54:24  curt
-% Initial add to repository
-%
+# Revision 1.2  1996/01/21  00:28:27  curt
+# Change field delimiter from : to \t.  Save account when done deleting records.
+# Update copyright date.
+#
+# Revision 1.1  1995/07/07  04:23:49  curt
+# Initial add to repository
+#
