@@ -1,12 +1,12 @@
 #!/usr/local/bin/perl
-#  engine.pl - the cbb 'engine'.
+#  engine.pl - the CBB 'engine'.
 #              This script implements a transaction abstract data type
 #              It encapsulates a list a transactions and the functions
 #              required to manipulate the transactions.
 #
 #  Written by Curtis Olson.  Started August 22, 1994.
 #
-#  Copyright (C) 1994  Curtis L. Olson  - curt@sledge.mn.org
+#  Copyright (C) 1994, 1995, 1996  Curtis L. Olson  - curt@sledge.mn.org
 #
 #  This program is free software; you can redistribute it and/or modify
 #  it under the terms of the GNU General Public License as published by
@@ -22,7 +22,7 @@
 #  along with this program; if not, write to the Free Software
 #  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
-# $Id: engine.pl,v 1.18 1995/02/23 05:08:45 curt Exp $
+# $Id: engine.pl,v 1.32 1996/02/11 20:23:58 curt Exp $
 # (Log is kept at end of this file)
 
 
@@ -43,7 +43,7 @@ if ( $logging != 0 && $logging != 1) {
 }
 
 if ( $debug != 0 && $debug != 1) {
-    # if not specified elsewhere, turn off debuging.
+    # if not specified elsewhere, turn off debugging.
     $debug = 0;			# 0 = off,  1 = on
 }
 
@@ -56,6 +56,7 @@ if ( $debug != 0 && $debug != 1) {
 # $current - specifies the "current" position in the @KEYS array
 # $current_file - full name of currently opened transaction file
 # %BALS - an associative array used to store account information
+# $version - version number (set in common.pl)
 
 open(DEBUG, ">debug") if $debug;
 
@@ -102,7 +103,7 @@ sub calc_trans {
 
     foreach $key (@KEYS) {
         ($date, $check, $desc, $debit, $credit, $cat, $com, $cleared, 
-        	$junk) = split(/:/, $TRANS{$key});
+        	$junk) = split(/\t/, $TRANS{$key});
 
 	$total = $total + $credit - $debit;
 	$count++;
@@ -119,7 +120,7 @@ sub calc_trans {
 	}
 
 	$TRANS{$key} = 
-	  "$date:$check:$desc:$debit:$credit:$cat:$com:$cleared:".
+	  "$date\t$check\t$desc\t$debit\t$credit\t$cat\t$com\t$cleared\t".
 	  	sprintf("%.2f", $total);
     }
 
@@ -147,7 +148,7 @@ sub create_trans {
     $calced = 0;
 
     ($date, $check, $desc, $debit, $credit, $cat, $com, $cleared, $total) =
-	split(/:/, $trans);
+	split(/\t/, $trans);
 
     if ( length($date) == 6 ) {
 	$date = "19$date";
@@ -155,14 +156,13 @@ sub create_trans {
 
     $key = &get_next_key($date);
 
-    $trans = "$date:$check:$desc:$debit:$credit:$cat:$com:$cleared:$total";
+    $trans = "$date\t$check\t$desc\t$debit\t$credit\t$cat\t$com\t$cleared\t$total";
 
     $TRANS{$key} = "$trans";
 
-    &log_txn($current_file, $key, $trans, "add:$current_file") if $logging;
-    print DEBUG "created:  $key:$trans\n" if $debug;
+    print DEBUG "created:  $key\t$trans\n" if $debug;
 
-    return "$key:$trans";
+    return "$key\t$trans";
 }
 
 
@@ -173,51 +173,86 @@ sub create_xfer {
 
     local($trans) = @_;
     local($orig_file) = $current_file;
-    local($file, $from_cat);
+    local($to_file, $from_cat);
 
     $sorted_keys = 0;
     $calced = 0;
 
     ($date, $check, $desc, $debit, $credit, $cat, $com, $cleared, $total) =
-	split(/:/, $trans);
-
-    $key = &get_next_key($date);
+	split(/\t/, $trans);
 
+    print DEBUG "(xfer) current_file = $current_file\n" if $debug;
     # determine the "from" category
-    $from_cat = "[".&file_basename($current_file)."]";
+    $from_cat = "[".&file_basename(&file_root($current_file))."]";
 
     # determine the "to" file name
-    $file = $cat;
-    chop($file);
-    $file = substr($file, 1);
-    print DEBUG "Transfer to ".&file_dirname($current_file)."/$file\n" 
-	if $debug;
+    $to_file = $cat;
+    chop($to_file);
+    $to_file = substr($to_file, 1);
+    $to_file = &file_dirname($current_file)."/$to_file";
+    print DEBUG "to file = '$to_file' ($to_file.cbb)\n" if $debug;
+    if ( -e "$to_file.cbb" ) {
+	$to_file .= ".cbb";
+    } elsif ( -e "$to_file.dir" ) {
+	$to_file .= ".dir";
+    } else {
+	return "error";
+    }
 
-    # open the "to" account
-    &load_trans(&file_dirname($current_file)."/$file");
+    print DEBUG "Transfer to $to_file\n" if $debug;
 
     # create the "to" transaction
-    $key = &get_next_key($date);
-    $TRANS{$key} = "$date:$check:$desc:".$credit.":".$debit.":".
-	$from_cat.":$com:$cleared:$total";
+    $to_trans = "$date\t$check\t$desc\t".$credit."\t".$debit."\t".
+		$from_cat."\t$com\t$cleared\t$total";
 
-    &log_txn($current_file, $key, "$date:$check:$desc:".$credit.":".
-	     $debit.":".$from_cat.":$com:$cleared:$total", 
-	     "add:$current_file") if $logging;
-    print DEBUG "created:  $key:$date:$check:$desc:".$credit.":".
-	     $debit.":".$from_cat.":$com:$cleared:$total\n" if $debug;
+    if ( &file_extension($to_file) eq "dir" ) {
+	if ( &file_extension($orig_file) eq "cbb" ) {
+	    # we need special handling here to preserve the .cbb file
+	    # save the current transactions to a temporary file
+	    $result = &save_trans("$orig_file.$$.tmp");
+	    return "error" if ( $result eq "error" );
+            %TRANS = ();  # clear out any transactions from the current file
+	}
 
-    # re-open orig account
-    &load_trans($orig_file);
+        # open the "to" account
+        $result = &load_trans($to_file);
+	return "error" if ( $result eq "error" );
+
+	$result = &create_trans($to_trans);
+
+	if ( &file_extension($orig_file) eq "cbb" ) {
+	    $result = &load_cbb_trans("$orig_file.$$.tmp");
+	    return "error" if ( $result eq "error" );
+	    unlink("$orig_file.$$.tmp");
+	    $current_file = $orig_file;
+	} else {
+            # re-open orig account
+            $result = &load_trans($orig_file);
+	    return "error" if ( $result eq "error" );
+        }
+    } else {
+	$result = &append_trans($to_file, $to_trans);
+	return "error" if ( $result eq "error" );
+    }
 
     # create the "from" transaction
-    $key = &get_next_key($date);
-    $TRANS{$key} = "$trans";
+    $result = &create_trans($trans);
 
-    &log_txn($current_file, $key, $trans, "add:$current_file") if $logging;
-    print DEBUG "created:  $key:$trans\n" if $debug;
+    return "$key\t$trans";
+}
 
-    return "$key:$trans";
+
+# append a transaction to the specified file
+sub append_trans {
+    local($to_file, $to_trans) = @_;
+
+    print DEBUG "xfer to $to_file: $to_trans\n" if $debug;
+
+    open(TOFILE, ">>$to_file") || return "error";
+    print TOFILE "$to_trans\n";
+    close(TOFILE);
+
+    return "$to_trans";
 }
 
 
@@ -230,7 +265,7 @@ sub update_trans {
     $sorted_keys = 0;
     $calced = 0;
 
-    ($key, $trans) = split(/:/, $keyed_trans, 2);
+    ($key, $trans) = split(/\t/, $keyed_trans, 2);
 
     &delete_trans($key);
     $result = &create_trans($trans);
@@ -250,11 +285,12 @@ sub delete_trans {
     $sorted_keys = 0;
     $calced = 0;
 
-    &log_txn($current_file, $key, $TRANS{$key}, "delete:$current_file") 
-	if $logging;
-
     delete $TRANS{$key};
 
+    if ($current > 0) {
+	--$current;
+    }
+
     print DEBUG "deleted:  $key\n" if $debug;
 
     return "ok";
@@ -274,7 +310,7 @@ sub next_trans {
     ++$current;
     $trans = $TRANS{$KEYS[$current]};
     if ( $trans ) {
-        return "$KEYS[$current]:$trans";
+        return "$KEYS[$current]\t$trans";
     } else {
         return "none";
     }
@@ -319,10 +355,10 @@ sub find_trans {
         }
     }
 
-    print DEBUG "found:  $key:$trans\n" if $debug;
+    print DEBUG "found:  $key\t$trans\n" if $debug;
 
     if ( $trans ) {
-        return "$key:$trans";
+        return "$key\t$trans";
     } else {
         return "none";
     }
@@ -348,7 +384,7 @@ sub first_trans {
     $current = 0;
     $trans = $TRANS{$KEYS[$current]};
     if ( $trans ) {
-        return "$KEYS[$current]:$trans";
+        return "$KEYS[$current]\t$trans";
     } else {
         return "none";
     }
@@ -357,8 +393,11 @@ sub first_trans {
 
 # returns the entire transaction list in one big chunk.
 sub all_trans {
+    # in: date
     # out: result
 
+    local($date_fmt) = @_;
+
     $| = 0;				# turn off buffer flushing
 
     if ($calced == 0) {
@@ -370,7 +409,44 @@ sub all_trans {
     }
 
     foreach $key (@KEYS) {
-	print ("$key:$TRANS{$key}\n");
+	# print ("$key\t$TRANS{$key}\n");
+        ($date, $check, $desc, $debit, $credit, $cat, $com, $cleared, $total) =
+	    split(/\t/, $TRANS{$key});
+
+        if ( length($date) == 6 ) {
+            ($year, $month, $day) = $date =~ /(\d\d)(\d\d)(\d\d)/;
+	    $year = "19" . $year;
+        } else {
+            ($year, $month, $day) = $date =~ /(\d\d\d\d)(\d\d)(\d\d)/
+        }
+
+        $checklen = length($check);
+        if ( $checklen > 5 ) {
+            $cutcheck = substr($check, $checklen - 5, 5);
+        } else {
+            $cutcheck = $check;
+        }
+
+        if ( $date_fmt == 1 ) {
+            $nicedate = "$month/$day/" . substr($year, 2, 2);
+        } else {
+            $nicedate = "$day/$month/" . substr($year, 2, 2);
+        }
+
+        $cutdesc = substr($desc, 0, 15);
+        $cutcom = substr($com, 0, 15);
+        if ( $cat =~ m/\|/ ) {
+            $nicecat = "-Splits-";
+        } else {
+            $nicecat = $cat;
+        }
+	$nicecat = substr($nicecat, 0, 9);
+
+        printf("%5s  %-8s  %-15s  %9.2f  %9.2f  %-1s  %9.2f %14s\n",
+                $cutcheck, $nicedate, $cutdesc, $debit, $credit, $cleared, 
+		$total, $key);
+        printf("%5s  %-8s  %-15s  %-9s %39s\n", "", "", $cutcom, $nicecat, 
+		$key);
     }
 
     $| = 1;				# turn buffer flushing back on
@@ -391,16 +467,16 @@ sub first_uncleared_trans {
     $current = 0;
     $trans = $TRANS{$KEYS[$current]};
     ($date, $check, $desc, $debit, $credit, $cat, $com, $cleared, $junk) = 
-    	    split(/:/, $trans);
+    	    split(/\t/, $trans);
     while ( $cleared eq "x" ) {
         ++$current;
         $trans = $TRANS{$KEYS[$current]};
         ($date, $check, $desc, $debit, $credit, $cat, $com, $cleared, $junk) = 
-    	        split(/:/, $trans);
+    	        split(/\t/, $trans);
     }
 
     if ( $trans ) {
-        return "$KEYS[$current]:$trans";
+        return "$KEYS[$current]\t$trans";
     } else {
         return "none";
     }
@@ -420,16 +496,16 @@ sub next_uncleared_trans {
     ++$current;
     $trans = $TRANS{$KEYS[$current]};
     ($date, $check, $desc, $debit, $credit, $cat, $com, $cleared, $junk) = 
-    	    split(/:/, $trans);
+    	    split(/\t/, $trans);
     while ( $cleared eq "x" ) {
         ++$current;
         $trans = $TRANS{$KEYS[$current]};
         ($date, $check, $desc, $debit, $credit, $cat, $com, $cleared, $junk) = 
-    	        split(/:/, $trans);
+    	        split(/\t/, $trans);
     }
 
     if ( $trans ) {
-        return "$KEYS[$current]:$trans";
+        return "$KEYS[$current]\t$trans";
     } else {
         return "none";
     }
@@ -447,18 +523,16 @@ sub select_trans {
 
     $trans = $TRANS{$key};
     ($date, $check, $desc, $debit, $credit, $cat, $com, $cleared, $total) = 
-    	    split(/:/, $trans);
+    	    split(/\t/, $trans);
 
     $cleared = "*";
 
     $TRANS{$key} = 
-	  "$date:$check:$desc:$debit:$credit:$cat:$com:$cleared:$total";
+	  "$date\t$check\t$desc\t$debit\t$credit\t$cat\t$com\t$cleared\t$total";
 
-    &log_txn($current_file, $key, $TRANS{$key}, "_->*:$current_file") 
-	if $logging;
     print DEBUG "selected:  $key to be cleared\n" if $debug;
 
-    return "$key:$TRANS{$key}";
+    return "$key\t$TRANS{$key}";
 }
 
 
@@ -473,18 +547,16 @@ sub unselect_trans {
 
     $trans = $TRANS{$key};
     ($date, $check, $desc, $debit, $credit, $cat, $com, $cleared, $total) = 
-    	    split(/:/, $trans);
+    	    split(/\t/, $trans);
 
     $cleared = "";
 
     $TRANS{$key} = 
-	  "$date:$check:$desc:$debit:$credit:$cat:$com:$cleared:$total";
+	  "$date\t$check\t$desc\t$debit\t$credit\t$cat\t$com\t$cleared\t$total";
 
-    &log_txn($current_file, $key, $TRANS{$key}, "*->_:$current_file") 
-	if $logging;
     print DEBUG "unselected:  $key will not be cleared\n" if $debug;
 
-    return "$key:$TRANS{$key}";
+    return "$key\t$TRANS{$key}";
 }
 
 
@@ -501,16 +573,13 @@ sub clear_trans {
     foreach $key (@KEYS) {
         $trans = $TRANS{$key};
         ($date, $check, $desc, $debit, $credit, $cat, $com, $cleared, $total) = 
-    	        split(/:/, $trans);
+    	        split(/\t/, $trans);
 
 	if ( $cleared eq "*" ) {
             $cleared = "x";
 
             $TRANS{$key} = 
-	          "$date:$check:$desc:$debit:$credit:$cat:$com:$cleared:$total";
-
-	    &log_txn($current_file, $key, $TRANS{$key}, "*->x:$current_file") 
-		if $logging;
+	          "$date\t$check\t$desc\t$debit\t$credit\t$cat\t$com\t$cleared\t$total";
         }
     }
 }
@@ -537,51 +606,155 @@ sub init_trans {
 
 # make a new account
 sub make_acct {
-    # in: acct-name acct-desc
+    # in: acct-name acct-desc acct-type
     # out: result
     
+    local($name, $desc) = split(/ /, @_[0], 2);
     local($pos, $short_name);
-    local($name, $desc) = split(/ /, @_[0], 2);;
 
-    print DEBUG "Make account $name - $desc\n";
+    print DEBUG "Make account $name - $desc\n" if $debug;
+    # print "Make account $name - $desc\n";
 
-    dbmclose(TRANS);
-    dbmopen(%TRANS, "$name.txn", 0666);
+    print DEBUG "Making cbb account\n" if $debug;
 
-    dbmclose(BALS);
-    dbmopen(%BALS, "$name.bal", 0666);
-
-    $current_file = $name;
-
-    &log_txn($current_file, $name, $desc, "make_acct:$current_file") 
-	if $logging;
+    open(SAVE, ">$name.cbb.new");
+    close(SAVE);
+    unlink("$name.cbb.bak");
+    rename("$name.cbb", "$name.cbb.bak");
+    rename("$name.cbb.new", "$name.cbb");
+    
+    $current_file = "$name.cbb";
 
     # Assume we have category already open ... :| ??? :(
 
     # strip leading path from $name
-    &insert_cat("[".&file_basename($name)."]:$desc:");
+    &insert_cat("[".&file_basename($name)."]\t$desc\t");
+
+    # save the categories file before it gets toasted
+    &save_cats(&file_dirname($name) . "/categories");
 
     return "ok";
 }
 
 
-# load the data from a file
+# determine the file type and call the correct load routine
 sub load_trans {
+    # in: file base
+    # out: result
+
+    local($file) = @_;
+    local($ext) = &file_extension($file);
+
+    # print "$ext\n";
+    # print &file_root($file) . "\n";
+
+    print DEBUG "file extension is: $ext\n" if $debug;
+
+    return &load_cbb_trans($file);
+}
+
+
+# load the data from a cbb file
+sub load_cbb_trans {
+    # in: file name (including .cbb extension)
+    # out: result
+
+    local($file) = @_;
+    $sorted_keys = 0;
+    $calced = 0;
+
+    print DEBUG "Loading the cbb format file: $file\n" if $debug;
+
+    open(LOAD, "<$file") || return "error";
+
+    dbmclose(TRANS);    # close just in case the previous file was dbm
+    %TRANS = ();	# clear out any transactions from the previous file
+    $file_version = "";
+
+    while ( <LOAD> ) {
+	if ( m/^#/ ) {
+	    # toss the comment (but first check for any goodies.)
+	    if ( m/version/i ) {
+		($junk, $junk, $junk, $file_version) = split;
+		print DEBUG "Data file version = $file_version\n" if $debug;
+	    }
+	} else {
+            chop;
+	    if ( ! m/\t/ ) {
+		s/:/\t/g;
+		$_ = &fix_splits($_);
+	    }
+            &create_trans($_);
+	}
+    }
+
+    close(LOAD);
+
+    $current_file = $file;
+
+    return "ok";
+}
+
+
+sub fix_splits {
+    # in: transaction with old two field per record splits
+    # out: transaction with new three field per record splits
+
+    local($line) = @_;
+    local($i);
+
+    ($date, $check, $desc, $debit, $credit, $cat, $com, $cleared, $total) =
+	split(/\t/, $line);
+
+    if ( $cat =~ m/\|/ ) {
+        @cats = split(/\|/, $cat);
+
+        $i = 0;
+        $max = ($#cats - 1) / 2;
+        $newcat = "|";
+
+        while ( $i < $max ) {
+    	    $newcat .= $cats[$i * 2 + 1] . "||" . 
+		       $cats[$i * 2 + 2] . "|";
+	    $i++;
+        }
+    } else {
+	$newcat = $cat;
+    }
+
+    return "$date\t$check\t$desc\t$debit\t$credit\t$newcat\t$com\t$cleared\t$total";
+}
+
+
+# load the data from a dbm file
+sub load_dbm_trans {
     # in: file base name
     # out: result
 
     local($file) = @_;
+    local($temp);
 
-    if ( -e "$file.txn.dir" ) {
+    print DEBUG "Loading the dbm format file: $file\n" if $debug;
+
+    if ( -e "$file" ) {
 	$current_file = $file;
 	$sorted_keys = 0;
 	$calced = 0;
 
 	dbmclose(TRANS);
-	dbmopen(%TRANS, "$file.txn", 0666);
+	dbmopen(%TRANS, &file_root($file), 0666) || return "error";
 	
-	dbmclose(BALS);
-	dbmopen(%BALS, "$file.bal", 0666);
+	# test to see if this file is <tab> delimited
+	&sort_keys();
+	# never ever call calc_trans() at this point (or call something that
+	# calls it
+	if ( defined($TRANS{$KEYS[0]}) && ! ($TRANS{$KEYS[0]} =~ m/\t/) ) {
+	    print DEBUG "'$TRANS{$KEYS[0]}' = old version of CBB dbm file\n"
+		if $debug;
+	    return "error - old version of CBB dbm file";
+	} else {
+	    print DEBUG "valid txn: '$TRANS{$KEY[0]}'\n" if $debug;
+        }
 
 	return "ok";
     } else {
@@ -592,10 +765,13 @@ sub load_trans {
 
 # save all the precious data to a file
 sub save_trans {
-    # in: file base name
+    # in: file name (including .cbb extension)
     # out: result
 
     local($file) = @_;
+    local($auto_save_file);
+
+    print DEBUG "Saving the cbb format file: $file\n" if $debug;
 
     if ($calced == 0) {
 	&calc_trans();
@@ -605,7 +781,34 @@ sub save_trans {
 	&sort_keys();
     }
 
-    # this has become a no-op
+    open(SAVE, ">$file.new") || return "error";
+
+    # Print some header stuff
+    print (SAVE "# CBB Data File -- $file\n");
+    print (SAVE "#\n");
+    print (SAVE "# Version = $version_num\n");
+    print (SAVE "# Saved on (US Date Fmt) " . &nice_date("1") . " ");
+    print (SAVE "by $user_name\n");
+    print (SAVE "#\n");
+    print (SAVE "# date  check  desc  debit  credit  cat  com  cleared  total\n");
+    print (SAVE "# ----------------------------------------------------------\n");
+
+    foreach $key (@KEYS) {
+        print (SAVE "$TRANS{$key}\n");
+    }
+
+    close(SAVE);
+
+    unlink("$file.bak");
+    rename("$file", "$file.bak");
+    rename("$file.new", "$file");
+
+    $auto_save_file = &file_dirname($file) . "#" . &file_basename($file) . "#";
+    print DEBUG "auto_save_file = $auto_save_file\n" if $debug;
+    if ( -e $auto_save_file ) {
+	unlink("$auto_save_file");
+	unlink("$auto_save_file.bak");
+    }
 
     return "ok";
 }
@@ -613,6 +816,60 @@ sub save_trans {
 
 # ----------------------------------------------------------------------------
 # $Log: engine.pl,v $
+# Revision 1.32  1996/02/11  20:23:58  curt
+# Removed support for dbm account files.
+#
+# Revision 1.31  1996/02/05  01:49:02  curt
+# Changed several instances of cbb to CBB.
+#
+# Revision 1.30  1996/01/21  02:18:48  curt
+# Modified Files:  categories.pl common.pl engine.pl export.pl file.pl import.pl
+#                  log.pl memorized.pl reports.pl wrapper.pl
+#   Updated copyright date.
+#
+# Revision 1.29  1995/08/18  11:34:07  curt
+# Added support for the international date format.
+#
+# Revision 1.28  1995/08/03  22:58:02  curt
+# Added support for long check #'s.
+#
+# Revision 1.27  1995/07/21  03:37:26  curt
+# Fixed a really stupid bug with transfer transaction which caused them to fail.
+#
+# Revision 1.26  1995/07/20  11:18:55  curt
+# Spelling fixes ...
+#
+# Revision 1.25  1995/07/20  03:21:17  curt
+# Preformat transaction list entries, so tcl doesn't have to waste time
+# doing it.
+#
+# Revision 1.24  1995/07/20  02:51:43  curt
+# Mods to handle new split comment.
+#
+# Revision 1.23  1995/07/08  01:49:39  curt
+# Change delimiter from ":" to "\t"
+#
+# Revision 1.22  1995/06/06  01:34:52  curt
+# Modified Files:  categories.tk cbb engine.pl file.tk
+#   Added a Yes/No/Cancel dialog box, and used it in places
+#   Delete temporary autosave file after user requests a real save.
+#
+# Revision 1.21  1995/06/05  11:41:41  curt
+# Modified Files:  Todo cbb engine.pl file.tk log.pl wrapper.pl
+#   Fixed transfers between files.
+#   Reworked transaction logging.
+#   Added an auto-save feature.
+#   Reworked .cbbrc saving and loading
+#   Use '.dir' now instead of '.pag'
+#
+# Revision 1.20  1995/06/04  13:36:10  curt
+# Added support for dual file formats (text and dbm).
+# This involved modifications to make_acct(), load_trans(), save_trans().
+#
+# Revision 1.19  1995/04/24  01:57:22  curt
+# Split of menu setup functions into a separate file:  menu.tk
+# Started rearranging structure to support multiple file formats.
+#
 # Revision 1.18  1995/02/23  05:08:45  curt
 # Removed dependencies on tclX.
 #
@@ -638,7 +895,7 @@ sub save_trans {
 #
 # Revision 1.11  1994/10/31  23:14:50  clolson
 # Started tracking towards cbbsh (the text only version).  Chris Browne has
-# some good ideas, so I am trying to incorperate them, and make my stuff
+# some good ideas, so I am trying to incorporate them, and make my stuff
 # compatible with his.
 #
 # Revision 1.10  1994/10/31  15:01:41  curt
@@ -657,7 +914,7 @@ sub save_trans {
 # Added all-trans function.
 #
 # Revision 1.5  1994/10/14  17:05:18  clolson
-# Miscellaneous cleanups in preparation for releasing verion 0.40a
+# Miscellaneous cleanups in preparation for releasing version 0.40a
 #
 # Revision 1.4  1994/10/13  23:57:14  curt
 # Finished memorized transactions.
@@ -733,7 +990,7 @@ sub save_trans {
 #
 # Revision 1.5  1994/08/25  04:17:14  curt
 # Finished first stab at import_qif().
-# Also finished load_trans() and save_trans().
+# Also finished load_dbm_trans() and save_dbm_trans().
 #
 # Revision 1.4  1994/08/25  02:08:58  clolson
 # More work on .qif imports
