@@ -3,7 +3,7 @@
 #
 #  Written by Curtis Olson.  Started October 19, 1994.
 #
-#  Copyright (C) 1994  Curtis L. Olson  - curt@sledge.mn.org
+#  Copyright (C) 1994, 1995, 1996  Curtis L. Olson  - curt@sledge.mn.org
 #
 #  This program is free software; you can redistribute it and/or modify
 #  it under the terms of the GNU General Public License as published by
@@ -19,12 +19,12 @@
 #  along with this program; if not, write to the Free Software
 #  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
-# $Id: export.pl,v 1.3 1995/01/08 21:18:32 curt Exp $
+# $Id: export.pl,v 1.6 1996/01/21 02:18:49 curt Exp $
 # (Log is kept at end of this file)
 
 
-# export data to the old CBB format
-sub export_old_cbb {
+# save data in the CBB format
+sub save_cbb {
     # in: file base name
     # out: result
 
@@ -78,7 +78,7 @@ sub export_qif {
     foreach $key (keys (%TRANS))
      {
         ($date, $check, $desc, $debit, $credit, $cat, $com, $cleared,
-               $junk) = split(/:/, $TRANS{$key});
+               $junk) = split(/\t/, $TRANS{$key});
      
      # Handle date
      $yr = substr($date, 2, 2);
@@ -129,6 +129,17 @@ sub export_qif {
 
 # ----------------------------------------------------------------------------
 # $Log: export.pl,v $
+# Revision 1.6  1996/01/21  02:18:49  curt
+# Modified Files:  categories.pl common.pl engine.pl export.pl file.pl import.pl
+#                  log.pl memorized.pl reports.pl wrapper.pl
+#   Updated copyright date.
+#
+# Revision 1.5  1995/07/08  01:47:42  curt
+# Change delimiter from ":" to "\t"
+#
+# Revision 1.4  1995/06/04  13:39:28  curt
+# renamed export_old_cbb() to save_cbb()
+#
 # Revision 1.3  1995/01/08  21:18:32  curt
 # Fixed bug (introduced by myself ... 4 digit years) in quicken export
 # date format.
