@@ -3,7 +3,7 @@
 #
 #  Written by Curtis Olson.  Started August 25, 1994.
 #
-#  Copyright (C) 1994  Curtis L. Olson  - curt@sledge.mn.org
+#  Copyright (C) 1994, 1995, 1996  Curtis L. Olson  - curt@sledge.mn.org
 #
 #  This program is free software; you can redistribute it and/or modify
 #  it under the terms of the GNU General Public License as published by
@@ -19,7 +19,7 @@
 #  along with this program; if not, write to the Free Software
 #  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
-# $Id: import.pl,v 1.2 1994/11/01 22:39:10 clolson Exp $
+# $Id: import.pl,v 1.6 1996/01/21 02:18:50 curt Exp $
 # (Log is kept at end of this file)
 
 
@@ -31,8 +31,8 @@ unshift(@INC, $cbb_incl_dir);
 require "common.pl";
 
 
-# import the data from the old CBB format
-sub import_old_cbb {
+# load data from a CBB format file
+sub load_cbb {
     # in: file base name
     # out: result
 
@@ -43,8 +43,13 @@ sub import_old_cbb {
     open(LOAD, "<$file") || return "error";
 
     while ( <LOAD> ) {
-	chop;
-	&create_trans($_);
+	if ( m/^\s*#/ ) {
+	    # toss the comment (any line whose 1st non-whitespace character is
+	    #                   the pound sign.)
+	} else {
+	    chop;
+	    &create_trans($_);
+	}
     }
 
     close(LOAD);
@@ -69,7 +74,7 @@ sub import_qif {
 
     while ( <QIF> ) {
 	chop;			# get rid of that pesky newline.
-	s/:/-/g;		# eliminate our delimiter characters from
+	# s/:/-/g;		# eliminate our delimiter characters from
 	s/\|/-/g;		# the import file.
 	s/\r//g;		# strip the dos ^M if needed
 	if ( m/^\!/ ) {
@@ -121,9 +126,14 @@ sub import_qif {
 	    }
 	} elsif ( m/^E/ ) {
 	    # split comment
-	    $split = $split.substr($_,1)."|"
+	    $split = $split.substr($_,1)."|";
+	    $found_split_com = 1;
 	} elsif ( m/^\$/ ) {
 	    # split amount
+	    if ( ! $found_split_com ) {
+		$split = $split . "|";
+		$found_split_com = 0;
+	    }
 	    $split = $split.substr($_,1)."|";
 	} elsif ( m/^M/ ) {
 	    # coMment
@@ -135,7 +145,7 @@ sub import_qif {
 		$cat = $split;
 	    }
 	    &create_trans(
-	    	"$date:$check:$desc:$debit:$credit:$cat:$com:$cleared:0.00" );
+	    	"$date\t$check\t$desc\t$debit\t$credit\t$cat\t$com\t$cleared\t0.00" );
 	    ($date, $check, $desc, $debit, $credit, $cat, $split, $com, 
 	    	$cleared) = ("", "", "", "", "", "", "", "", "");
 	} elsif ( $_ eq "" ) {
@@ -156,6 +166,21 @@ sub import_qif {
 
 # ----------------------------------------------------------------------------
 # $Log: import.pl,v $
+# Revision 1.6  1996/01/21  02:18:50  curt
+# Modified Files:  categories.pl common.pl engine.pl export.pl file.pl import.pl
+#                  log.pl memorized.pl reports.pl wrapper.pl
+#   Updated copyright date.
+#
+# Revision 1.5  1995/07/20  02:51:45  curt
+# Mods to handle new split comment.
+#
+# Revision 1.4  1995/07/08  01:46:59  curt
+# Change delimiter from ":" to "\t"
+#
+# Revision 1.3  1995/06/04  13:40:29  curt
+# Renamed import_old_cbb() to load_cbb() and added code to ignore lines
+# beginning with '#'
+#
 # Revision 1.2  1994/11/01  22:39:10  clolson
 # Added log.pl --> implemented logging.
 # Worked on install script.
