@@ -3,7 +3,7 @@
 #
 #  Written by Curtis Olson.  Started October 13, 1994.
 #
-#  Copyright (C) 1994  Curtis L. Olson  - curt@sledge.mn.org
+#  Copyright (C) 1994, 1995, 1996  Curtis L. Olson  - curt@sledge.mn.org
 #
 #  This program is free software; you can redistribute it and/or modify
 #  it under the terms of the GNU General Public License as published by
@@ -19,7 +19,7 @@
 #  along with this program; if not, write to the Free Software
 #  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
-# $Id: memorized.pl,v 1.2 1994/11/01 22:39:18 clolson Exp $
+# $Id: memorized.pl,v 1.4 1996/01/21 02:18:51 curt Exp $
 # (Log is kept at end of this file)
 
 # WARNING:  This file must be "required" after the main transaction file.
@@ -47,7 +47,7 @@ sub insert_mem {
     local($trans) = @_;
 
     ($date, $check, $desc, $debit, $credit, $cat, $com, $cleared, $total) =
-	split(/:/, $trans);
+	split(/\t/, $trans);
 
     $MEMS{$desc} = $trans;
 
@@ -92,7 +92,7 @@ sub find_mem {
     if ( $desc ne "" ) {
         foreach $memkey (@MEMKEYS) {
 	    if ( $memkey =~ m/^$desc/i ) {
-	        return "$desc:$MEMS{$memkey}";
+	        return "$desc\t$MEMS{$memkey}";
 	    }
         }
     }
@@ -109,6 +109,14 @@ sub find_mem {
 
 # ----------------------------------------------------------------------------
 # $Log: memorized.pl,v $
+# Revision 1.4  1996/01/21  02:18:51  curt
+# Modified Files:  categories.pl common.pl engine.pl export.pl file.pl import.pl
+#                  log.pl memorized.pl reports.pl wrapper.pl
+#   Updated copyright date.
+#
+# Revision 1.3  1995/07/08  01:47:00  curt
+# Change delimiter from ":" to "\t"
+#
 # Revision 1.2  1994/11/01  22:39:18  clolson
 # Added log.pl --> implemented logging.
 # Worked on install script.
