@@ -1,9 +1,9 @@
 #!/usr/local/bin/perl
-#  wrapper.pl - a command parsing wrapper for the cbb 'engine'.
+#  wrapper.pl - a command parsing wrapper for the CBB 'engine'.
 #
 #  Written by Curtis Olson.  Started August 22, 1994.
 #
-#  Copyright (C) 1994  Curtis L. Olson  - curt@sledge.mn.org
+#  Copyright (C) 1994, 1995, 1996  Curtis L. Olson  - curt@sledge.mn.org
 #
 #  This program is free software; you can redistribute it and/or modify
 #  it under the terms of the GNU General Public License as published by
@@ -19,21 +19,29 @@
 #  along with this program; if not, write to the Free Software
 #  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
-# $Id: wrapper.pl,v 1.9 1995/02/23 05:13:14 curt Exp $
+# $Id: wrapper.pl,v 1.18 1996/02/05 01:49:04 curt Exp $
 # (Log is kept at end of this file)
 
 
-# specify the installed location of the necessary pieces.
-$cbb_incl_dir = ".";
-unshift(@INC, $cbb_incl_dir);
-
-
 $logging = 1;			# 0 = off,  1 = on
 $debug = 1;			# 0 = off,  1 = on
 
 
+# get user name
+@pw = getpwuid($<);
+
+$user_name = $pw[0]
+     || $ENV{LOGNAME}
+     || die "No user name!";
+
+
+# specify the installed location of the necessary pieces.
+$cbb_incl_dir = ".";
+unshift(@INC, $cbb_incl_dir);
+
 require "engine.pl";
 require "categories.pl";
+require "file.pl";
 require "memorized.pl";	
 require "import.pl";
 require "export.pl";
@@ -55,15 +63,19 @@ while (<>) {
     if ($command eq "create_trans") {
 	print DEBUG "calling create_trans($arg)\n" if $debug;
 	print &create_trans($arg)."\n";
+	&log_txn($_) if $logging;
     } elsif ($command eq "create_xfer") {
 	print DEBUG "calling create_xfer($arg)\n" if $debug;
 	print &create_xfer($arg)."\n";
+	&log_txn($_) if $logging;
     } elsif ($command eq "update_trans") {
 	print DEBUG "calling update_trans($arg)\n" if $debug;
 	print &update_trans($arg)."\n";
+	&log_txn($_) if $logging;
     } elsif ($command eq "delete_trans") {
 	print DEBUG "calling delete_trans($arg)\n" if $debug;
 	print &delete_trans($arg)."\n";
+	&log_txn($_) if $logging;
     } elsif ($command eq "next_trans") {
 	print DEBUG "next_trans()\n" if $debug;
 	print &next_trans()."\n";
@@ -79,8 +91,8 @@ while (<>) {
 	print DEBUG "first_trans()\n" if $debug;
 	print &first_trans()."\n";
     } elsif ($command eq "all_trans") {
-	print DEBUG "all_trans()\n" if $debug;
-	print &all_trans()."\n";
+	print DEBUG "all_trans($arg)\n" if $debug;
+	print &all_trans($arg)."\n";
     } elsif ($command eq "last_trans") {
 	print "last_trans()\n";
     } elsif ($command eq "first_uncleared_trans") {
@@ -96,12 +108,15 @@ while (<>) {
     } elsif ($command eq "select_trans") {
 	print DEBUG "select_trans()\n" if $debug;
 	print &select_trans($arg)."\n";
+	&log_txn($_) if $logging;
     } elsif ($command eq "unselect_trans") {
 	print DEBUG "unselect_trans()\n" if $debug;
 	print &unselect_trans($arg)."\n";
+	&log_txn($_) if $logging;
     } elsif ($command eq "clear_trans") {
 	print DEBUG "clear_trans()\n" if $debug;
 	print &clear_trans()."\n";
+	&log_txn($_) if $logging;
     } elsif ($command eq "get_cleared_bal") {
 	print DEBUG "get_cleared_bal()\n" if $debug;
 	print &get_cleared_bal()."\n";
@@ -113,24 +128,34 @@ while (<>) {
     } elsif ($command eq "make_acct") {
 	print DEBUG "calling make_acct($arg)\n" if $debug;
 	print &make_acct($arg)."\n";
+	&log_txn($_) if $logging;
     } elsif ($command eq "load_trans") {
 	print DEBUG "calling load_trans($arg)\n" if $debug;
 	print &load_trans($arg)."\n";
-    } elsif ($command eq "import_old_cbb") {
-	print DEBUG "calling import_old_cbb($arg)\n" if $debug;
-	print &import_old_cbb($arg)."\n";
+	&log_txn($_) if $logging;
+    } elsif ($command eq "load_cbb") {
+	print DEBUG "calling load_cbb($arg)\n" if $debug;
+	print &load_cbb($arg)."\n";
+	&log_txn($_) if $logging;
     } elsif ($command eq "import_qif") {
 	print DEBUG "calling import_qif($arg)\n" if $debug;
 	print &import_qif($arg)."\n";
-    } elsif ($command eq "export_old_cbb") {
-	print DEBUG "calling export_old_cbb($arg)\n" if $debug;
-	print &export_old_cbb($arg)."\n";
+	&log_txn($_) if $logging;
+    } elsif ($command eq "save_cbb") {
+	print DEBUG "calling save_cbb($arg)\n" if $debug;
+	print &save_cbb($arg)."\n";
+	&log_txn($_) if $logging;
     } elsif ($command eq "export_qif") {
 	print DEBUG "calling export_qif($arg)\n" if $debug;
 	print &export_qif($arg)."\n";
+	&log_txn($_) if $logging;
     } elsif ($command eq "save_trans") {
 	print DEBUG "calling save_trans($arg)\n" if $debug;
 	print &save_trans($arg)."\n";
+	&log_txn($_) if $logging;
+    } elsif ($command eq "auto_save_trans") {
+	print DEBUG "calling auto_save_trans($arg)\n" if $debug;
+	&save_trans($arg);
     } elsif ($command eq "rehash_mems") {
 	print DEBUG "calling rehash_mems()\n" if $debug;
 	print &rehash_mems()."\n";
@@ -143,24 +168,27 @@ while (<>) {
     } elsif ($command eq "edit_cat") {
 	print DEBUG "calling edit_cat($arg)\n" if $debug;
 	print &edit_cat($arg)."\n";
+	&log_txn($_) if $logging;
     } elsif ($command eq "insert_cat") {
 	print DEBUG "calling insert_cat($arg)\n" if $debug;
 	print &insert_cat($arg)."\n";
+	&log_txn($_) if $logging;
     } elsif ($command eq "delete_cat") {
 	print DEBUG "calling delete_cat($arg)\n" if $debug;
 	print &delete_cat($arg)."\n";
+	&log_txn($_) if $logging;
     } elsif ($command eq "all_cats") {
 	print DEBUG "calling all_cats()\n";
         print &all_cats()."\n";
     } elsif ($command eq "find_cat") {
 	print DEBUG "calling find_cat($arg)\n";
         print &find_cat($arg)."\n";
-    } elsif ($command eq "import_cats") {
-	print DEBUG "calling import_cats($arg)\n" if $debug;
-	print &import_cats($arg)."\n";
     } elsif ($command eq "load_cats") {
 	print DEBUG "calling load_cats($arg)\n" if $debug;
 	print &load_cats($arg)."\n";
+    } elsif ($command eq "load_dbm_cats") {
+	print DEBUG "calling load_dbm_cats($arg)\n" if $debug;
+	print &load_dbm_cats($arg)."\n";
     } elsif ($command eq "save_cats") {
 	print DEBUG "calling save_cats($arg)\n" if $debug;
 	print &save_cats($arg)."\n";
@@ -174,11 +202,14 @@ while (<>) {
 	print DEBUG "calling rep_txn_by_cat_short($arg)\n" if $debug;
 	print &rep_txn_by_cat_short($arg)."\n"
     } elsif ($command eq "nice_date") {
-	print DEBUG "calling nice_date()\n" if $debug;
-	print &nice_date()."\n"
+	print DEBUG "calling nice_date($arg)\n" if $debug;
+	print &nice_date($arg)."\n"
     } elsif ($command eq "raw_date") {
 	print DEBUG "calling raw_date()\n" if $debug;
 	print &raw_date()."\n"
+    } elsif ($command eq "get_files") {
+	print DEBUG "get_files($arg)\n" if $debug;
+	print &get_files($arg)."\n";
     } elsif ($command eq "quit") {
 	print DEBUG "exiting\n" if $debug;
 	exit(0);
@@ -195,6 +226,42 @@ while (<>) {
 
 # ----------------------------------------------------------------------------
 # $Log: wrapper.pl,v $
+# Revision 1.18  1996/02/05  01:49:04  curt
+# Changed several instances of cbb to CBB.
+#
+# Revision 1.17  1996/01/21  02:18:53  curt
+# Modified Files:  categories.pl common.pl engine.pl export.pl file.pl import.pl
+#                  log.pl memorized.pl reports.pl wrapper.pl
+#   Updated copyright date.
+#
+# Revision 1.16  1995/08/18  11:34:09  curt
+# Added support for the international date format.
+#
+# Revision 1.15  1995/07/20  11:18:58  curt
+# Spelling fixes ...
+#
+# Revision 1.14  1995/07/09  03:24:39  curt
+# Tweaked logging.
+#
+# Revision 1.13  1995/07/08  01:46:12  curt
+# Keep track of user name
+#
+# Revision 1.12  1995/06/05  11:41:46  curt
+# Modified Files:  Todo cbb engine.pl file.tk log.pl wrapper.pl
+#   Fixed transfers between files.
+#   Reworked transaction logging.
+#   Added an auto-save feature.
+#   Reworked .cbbrc saving and loading
+#   Use '.dir' now instead of '.pag'
+#
+# Revision 1.11  1995/06/04  13:31:23  curt
+# Added support for dual file formats (text and dbm).
+# Categories are now saved in text file format rather than dbm format.
+#
+# Revision 1.10  1995/04/24  01:57:27  curt
+# Split of menu setup functions into a separate file:  menu.tk
+# Started rearranging structure to support multiple file formats.
+#
 # Revision 1.9  1995/02/23  05:13:14  curt
 # Removed dependencies on tclX (wishx).
 #
@@ -219,7 +286,7 @@ while (<>) {
 #
 # Revision 1.2  1994/10/31  23:14:53  clolson
 # Started tracking towards cbbsh (the text only version).  Chris Browne has
-# some good ideas, so I am trying to incorperate them, and make my stuff
+# some good ideas, so I am trying to incorporate them, and make my stuff
 # compatible with his.
 #
 # Revision 1.1  1994/10/31  15:18:53  curt
